@@ -8,7 +8,7 @@ calc_prob.v5 <-
   function(iIndex, A, AXsi, B, xsi, theta, 
            nnodes, maxK, recalc=TRUE){
     if(recalc){
-      AXsi.tmp <- array( tensor( A[iIndex,,, drop = FALSE], xsi, 3, 1 ) , 
+      AXsi.tmp <- array( tensor::tensor( A[iIndex,,, drop = FALSE], xsi, 3, 1 ) , 
                          dim = c( length(iIndex) , maxK , nnodes ) )
       AXsi[iIndex,] = AXsi.tmp[,,1]
     } else {
